#ifndef NT2_INCLUDE_FUNCTIONS_ADDS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ADDS_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/adds.hpp>

#endif
